complete -c kmon -n "__fish_use_subcommand" -s a -l accent-color -d 'Set the accent color using hex or color name' -r
complete -c kmon -n "__fish_use_subcommand" -s c -l color -d 'Set the main color using hex or color name' -r
complete -c kmon -n "__fish_use_subcommand" -s t -l tickrate -d 'Set the refresh rate of the terminal' -r
complete -c kmon -n "__fish_use_subcommand" -s r -l reverse -d 'Reverse the kernel module list'
complete -c kmon -n "__fish_use_subcommand" -s u -l unicode -d 'Show Unicode symbols for the block titles'
complete -c kmon -n "__fish_use_subcommand" -s h -l help -d 'Print help'
complete -c kmon -n "__fish_use_subcommand" -s V -l version -d 'Print version'
complete -c kmon -n "__fish_use_subcommand" -f -a "sort" -d 'Sort kernel modules'
complete -c kmon -n "__fish_use_subcommand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c kmon -n "__fish_seen_subcommand_from sort" -s s -l size -d 'Sort modules by their sizes'
complete -c kmon -n "__fish_seen_subcommand_from sort" -s n -l name -d 'Sort modules by their names'
complete -c kmon -n "__fish_seen_subcommand_from sort" -s d -l dependent -d 'Sort modules by their dependent modules'
complete -c kmon -n "__fish_seen_subcommand_from sort" -s h -l help -d 'Print help'
complete -c kmon -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from help" -f -a "sort" -d 'Sort kernel modules'
complete -c kmon -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
